==> setup-2.249.2.10-1-src.tar.bz2: setup-0/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by res.rc
//
#define IDS_ROOT_SLASH                  1
#define IDS_ROOT_SPACE                  2
#define IDS_CWD_NONEMPTY                3
#define IDS_MIRROR_LST                  6
#define IDS_DIALOG_FAILED               7
#define IDS_CYGWIN_FUNC_MISSING         8
#define IDS_DOWNLOAD_SHORT              9
#define IDS_ERR_OPEN_WRITE              10
#define IDS_SETUPINI_MISSING            11
#define IDS_OLD_SETUPINI                12
#define IDS_ERR_RENAME                  13
#define IDS_NOTHING_INSTALLED           14
#define IDS_INSTALL_COMPLETE            15
#define IDS_ERR_OPEN_READ               16
#define IDS_ROOT_ABSOLUTE               17
#define IDS_DOWNLOAD_COMPLETE           18
#define IDS_CVSID                       19
#define IDS_NOLOGFILE                   20
#define IDS_UNINSTALL_COMPLETE          21
#define IDS_WININET                     22
#define IDS_ERR_CHDIR                   23
#define IDS_OLD_SETUP_VERSION           24
#define IDS_DOWNLOAD_FAILED             25
#define IDS_DOWNLOAD_INCOMPLETE         26
#define IDS_INSTALL_INCOMPLETE          27
#define IDS_VERSION_INFO                28
#define IDS_CYGWIN_SETUP                29
#define IDS_CYGWIN_SETUP_WITH_PROGRESS  30
#define IDD_ROOT                        101
#define IDD_SOURCE                      102
#define IDD_OTHER_URL                   103
#define IDD_SITE                        104
#define IDD_NET                         105
#define IDD_DLSTATUS                    106
#define IDD_S_LOAD_INI                  107
#define IDD_S_FROM_CWD                  108
#define IDD_CHOOSE                      109
#define IDD_S_DOWNLOAD                  110
#define IDD_S_INSTALL                   111
#define IDD_INSTATUS                    112
#define IDD_DESKTOP                     113
#define IDD_PROXY_AUTH                  114
#define IDD_S_POSTINSTALL               115
#define IDD_NET_AUTH                    116
#define IDD_SPLASH                      117
#define IDB_SPIN                        118
#define IDB_RTARROW                     119
#define IDI_SPIN                        120
#define IDI_CYGWIN                      121
#define IDD_LOCAL_DIR                   122
#define IDB_CHECK_YES                   123
#define IDB_CHECK_NO                    124
#define IDB_CHECK_NA                    125
#define IDD_FTP_AUTH                    126
#define IDD_CHOOSER                     127
#define IDC_SOURCE_DOWNLOAD             1000
#define IDC_SOURCE_NETINST              1001
#define IDC_SOURCE_CWD                  1002
#define IDC_ROOT_DIR                    1003
#define IDC_ROOT_BROWSE                 1004
#define IDC_ROOT_TEXT                   1005
#define IDC_ROOT_BINARY                 1006
#define IDC_URL_LIST                    1007
#define IDC_SITE_NEXT                   1008
#define IDC_BACK                        1009
#define IDC_OTHER_URL                   1010
#define IDC_NET_IE5                     1011
#define IDC_NET_DIRECT                  1012
#define IDC_NET_PROXY                   1013
#define IDC_PROXY_HOST                  1014
#define IDC_PROXY_PORT                  1015
#define IDC_PROXY_USER                  1016
#define IDC_DLS_PROGRESS                1019
#define IDC_DLS_URL                     1020
#define IDC_DLS_RATE                    1021
#define IDC_INS_PKG                     1022
#define IDC_INS_FILE                    1023
#define IDC_INS_DISKFULL                1024
#define IDC_INS_IPROGRESS               1025
#define IDC_INS_PPROGRESS               1026
#define IDC_ROOT_SYSTEM                 1028
#define IDC_ROOT_USER                   1029
#define IDC_NET_USER                    1030
#define IDC_NET_PASSWD                  1031
#define IDC_VERSION                     1033
#define IDC_LISTVIEW_POS                1034
#define IDC_CHOOSE_VIEW                 1035
#define IDC_CHOOSE_EXP                  1036
#define IDC_CHOOSE_CURR                 1037
#define IDC_CHOOSE_PREV                 1038
#define IDC_CHOOSE_LIST                 1039
#define IDC_INS_ACTION                  1040
#define IDC_ROOT_DESKTOP                1041
#define IDC_ROOT_MENU                   1042
#define IDC_LOCAL_DIR_BROWSE            1043
#define IDC_LOCAL_DIR                   1044
#define IDC_DLS_PPROGRESS               1045
#define IDC_DLS_IPROGRESS               1046
#define IDC_DLS_PROGRESS_TEXT           1047
#define IDC_DLS_PPROGRESS_TEXT          1048
#define IDC_DLS_IPROGRESS_TEXT          1049
#define IDC_CHOOSE_INST_TEXT            1050
#define IDC_CHOOSE_VIEWCAPTION          1051
#define IDC_CHOOSE_LISTHEADER           1052
#define IDC_INS_BL_PACKAGE              1053
#define IDC_INS_BL_TOTAL                1054
#define IDC_INS_BL_DISK                 1055
#define IDC_STATIC_HEADER_TITLE         1060
#define IDC_STATIC_WELCOME_TITLE        1061
#define IDC_EDIT_USER_URL               1062
#define IDC_BUTTON_ADD_URL              1063
#define IDS_REBOOT_REQUIRED		1064
#define IDS_CORRUPT_PACKAGE		1065
#define IDS_INSTALL_ERROR		1066
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_3D_CONTROLS                     1
#define _APS_NEXT_RESOURCE_VALUE        129
#define _APS_NEXT_COMMAND_VALUE         40003
#define _APS_NEXT_CONTROL_VALUE         1067
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> setup-2.340.2.5-1-src.tar.bz2: setup-0/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by res.rc
//
#define IDS_ROOT_SLASH                  1
#define IDS_ROOT_SPACE                  2
#define IDS_CWD_NONEMPTY                3
#define IDS_MIRROR_LST                  6
#define IDS_DIALOG_FAILED               7
#define IDS_CYGWIN_FUNC_MISSING         8
#define IDS_DOWNLOAD_SHORT              9
#define IDS_ERR_OPEN_WRITE              10
#define IDS_SETUPINI_MISSING            11
#define IDS_OLD_SETUPINI                12
#define IDS_ERR_RENAME                  13
#define IDS_NOTHING_INSTALLED           14
#define IDS_INSTALL_COMPLETE            15
#define IDS_ERR_OPEN_READ               16
#define IDS_ROOT_ABSOLUTE               17
#define IDS_DOWNLOAD_COMPLETE           18
#define IDS_CVSID                       19
#define IDS_NOLOGFILE                   20
#define IDS_UNINSTALL_COMPLETE          21
#define IDS_WININET                     22
#define IDS_ERR_CHDIR                   23
#define IDS_OLD_SETUP_VERSION           24
#define IDS_DOWNLOAD_FAILED             25
#define IDS_DOWNLOAD_INCOMPLETE         26
#define IDS_INSTALL_INCOMPLETE          27
#define IDS_VERSION_INFO                28
#define IDS_CYGWIN_SETUP                29
#define IDS_CYGWIN_SETUP_WITH_PROGRESS  30
#define IDD_ROOT                        101
#define IDD_SOURCE                      102
#define IDD_OTHER_URL                   103
#define IDD_SITE                        104
#define IDD_NET                         105
#define IDD_DLSTATUS                    106
#define IDD_S_LOAD_INI                  107
#define IDD_S_FROM_CWD                  108
#define IDD_CHOOSE                      109
#define IDD_S_DOWNLOAD                  110
#define IDD_S_INSTALL                   111
#define IDD_INSTATUS                    112
#define IDD_DESKTOP                     113
#define IDD_PROXY_AUTH                  114
#define IDD_S_POSTINSTALL               115
#define IDD_NET_AUTH                    116
#define IDD_SPLASH                      117
#define IDB_SPIN                        118
#define IDB_RTARROW                     119
#define IDI_SPIN                        120
#define IDI_CYGWIN                      121
#define IDD_LOCAL_DIR                   122
#define IDB_CHECK_YES                   123
#define IDB_CHECK_NO                    124
#define IDB_CHECK_NA                    125
#define IDD_FTP_AUTH                    126
#define IDD_CHOOSER                     127
#define IDD_VIRUS			128
#define IDC_SOURCE_DOWNLOAD             1000
#define IDC_SOURCE_NETINST              1001
#define IDC_SOURCE_CWD                  1002
#define IDC_ROOT_DIR                    1003
#define IDC_ROOT_BROWSE                 1004
#define IDC_ROOT_TEXT                   1005
#define IDC_ROOT_BINARY                 1006
#define IDC_URL_LIST                    1007
#define IDC_SITE_NEXT                   1008
#define IDC_BACK                        1009
#define IDC_OTHER_URL                   1010
#define IDC_NET_IE5                     1011
#define IDC_NET_DIRECT                  1012
#define IDC_NET_PROXY                   1013
#define IDC_PROXY_HOST                  1014
#define IDC_PROXY_PORT                  1015
#define IDC_PROXY_USER                  1016
#define IDC_DLS_PROGRESS                1019
#define IDC_DLS_URL                     1020
#define IDC_DLS_RATE                    1021
#define IDC_INS_PKG                     1022
#define IDC_INS_FILE                    1023
#define IDC_INS_DISKFULL                1024
#define IDC_INS_IPROGRESS               1025
#define IDC_INS_PPROGRESS               1026
#define IDC_ROOT_SYSTEM                 1028
#define IDC_ROOT_USER                   1029
#define IDC_NET_USER                    1030
#define IDC_NET_PASSWD                  1031
#define IDC_VERSION                     1033
#define IDC_LISTVIEW_POS                1034
#define IDC_CHOOSE_VIEW                 1035
#define IDC_CHOOSE_EXP                  1036
#define IDC_CHOOSE_CURR                 1037
#define IDC_CHOOSE_PREV                 1038
#define IDC_CHOOSE_LIST                 1039
#define IDC_INS_ACTION                  1040
#define IDC_ROOT_DESKTOP                1041
#define IDC_ROOT_MENU                   1042
#define IDC_LOCAL_DIR_BROWSE            1043
#define IDC_LOCAL_DIR                   1044
#define IDC_DLS_PPROGRESS               1045
#define IDC_DLS_IPROGRESS               1046
#define IDC_DLS_PROGRESS_TEXT           1047
#define IDC_DLS_PPROGRESS_TEXT          1048
#define IDC_DLS_IPROGRESS_TEXT          1049
#define IDC_CHOOSE_INST_TEXT            1050
#define IDC_CHOOSE_VIEWCAPTION          1051
#define IDC_CHOOSE_LISTHEADER           1052
#define IDC_INS_BL_PACKAGE              1053
#define IDC_INS_BL_TOTAL                1054
#define IDC_INS_BL_DISK                 1055
#define IDC_STATIC_HEADER_TITLE         1060
#define IDC_STATIC_WELCOME_TITLE        1061
#define IDC_EDIT_USER_URL               1062
#define IDC_BUTTON_ADD_URL              1063
#define IDS_REBOOT_REQUIRED		1064
#define IDS_CORRUPT_PACKAGE		1065
#define IDS_INSTALL_ERROR		1066
#define IDC_DISABLE_AV			1067
#define IDC_LEAVE_AV			1068
#define IDC_CHOOSE_KEEP			1069
#define IDS_MISSING_LOG			1070
#define IDS_SKIP_PACKAGE		1071
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_3D_CONTROLS                     1
#define _APS_NEXT_RESOURCE_VALUE        129
#define _APS_NEXT_COMMAND_VALUE         40003
#define _APS_NEXT_CONTROL_VALUE         1072
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
